@@ -30,7 +30,7 @@ class LED(utils.RGBObject):
         '''
         self.comms.send_header(
             self.device_id,
-            utils.PacketType.NET_PACKET_ID_RGBCONTROLLER_UPDATESINGLELED,
+            utils.PacketType.RGBCONTROLLER_UPDATESINGLELED,
             struct.calcsize("i3bx")
         )
         buff = struct.pack("i", self.id) + color.pack()
@@ -39,7 +39,7 @@ class LED(utils.RGBObject):
             self.update()
 
 
-class Zone(utils.RGBObject):
+class Zone(utils.RGBContainer):
     '''
     A class to represent a zone
     '''
@@ -59,22 +59,20 @@ class Zone(utils.RGBObject):
 
     def set_color(self, color: utils.RGBColor, start: int = 0, end: int = 0, fast: bool = False):
         '''
-        Sets the LEDs color in the zone between start and end
+        Sets the LEDs' color in the zone between start and end
 
-        :param color: the color to set the leds to
+        :param color: the color to set the LEDs to
         :param start: the first LED to change
-        :param end: the last LED to change
+        :param end: the first unchanged LED
         :param fast: If you care more about quickly setting colors than having correct internal state data, then set :code:`fast` to :code:`True`
         '''
         if end == 0:
             end = len(self.leds)
         self.comms.send_header(
             self.device_id,
-            utils.PacketType.NET_PACKET_ID_RGBCONTROLLER_UPDATEZONELEDS,
+            utils.PacketType.RGBCONTROLLER_UPDATEZONELEDS,
             struct.calcsize(f"IiH{3*(end)}b{(end)}x")
         )
-        print(self.id)
-        print(start, end)
         buff = struct.pack("iH", self.id, end) + b''.join((color.pack() for color in self._colors[:start])) + (color.pack())*(end - start)
         buff = struct.pack("I", len(buff)) + buff
         self.comms.send_data(buff)
@@ -83,11 +81,11 @@ class Zone(utils.RGBObject):
 
     def set_colors(self, colors: List[utils.RGBColor], start: int = 0, end: int = 0, fast: bool = False):
         '''
-        Sets the LEDs colors in the zone between start and end
+        Sets the LEDs' colors in the zone between start and end
 
-        :param colors: the list of colors, one per led
+        :param colors: the list of colors, one per LED
         :param start: the first LED to change
-        :param end: the last LED to change
+        :param end: the first unchanged LED
         :param fast: If you care more about quickly setting colors than having correct internal state data, then set :code:`fast` to :code:`True`
         '''
         if end == 0:
@@ -96,7 +94,7 @@ class Zone(utils.RGBObject):
             raise IndexError("Number of colors doesn't match number of LEDs")
         self.comms.send_header(
             self.device_id,
-            utils.PacketType.NET_PACKET_ID_RGBCONTROLLER_UPDATEZONELEDS,
+            utils.PacketType.RGBCONTROLLER_UPDATEZONELEDS,
             struct.calcsize(f"IIH{3*(end)}b{(end)}x")
         )
         buff = struct.pack("IH", self.id, end) + b''.join((color.pack() for color in self._colors[:start])) + b''.join((color.pack() for color in colors))
@@ -113,15 +111,16 @@ class Zone(utils.RGBObject):
         '''
         self.comms.send_header(
             self.device_id,
-            utils.PacketType.NET_PACKET_ID_RGBCONTROLLER_RESIZEZONE,
+            utils.PacketType.RGBCONTROLLER_RESIZEZONE,
             struct.calcsize("ii")
         )
         self.comms.send_data(struct.pack("ii", self.id, size))
         self.update()
 
-class Device(utils.RGBObject):
+
+class Device(utils.RGBContainer):
     '''
-    A class to represent a RGB Device
+    A class to represent an RGB Device
     '''
 
     def __init__(self, data: utils.ControllerData, device_id: int, network_client: NetworkClient):
@@ -141,18 +140,18 @@ class Device(utils.RGBObject):
 
     def set_color(self, color: utils.RGBColor, start: int = 0, end: int = 0, fast: bool = False):
         '''
-        Sets the LEDs color between start and end
+        Sets the LEDs' color between start and end
 
-        :param color: the color to set the leds to
+        :param color: the color to set the LED(s) to
         :param start: the first LED to change
-        :param end: the last LED to change
+        :param end: the first unchanged LED
         :param fast: If you care more about quickly setting colors than having correct internal state data, then set :code:`fast` to :code:`True`
         '''
         if end == 0:
             end = len(self.leds)
         self.comms.send_header(
             self.id,
-            utils.PacketType.NET_PACKET_ID_RGBCONTROLLER_UPDATELEDS,
+            utils.PacketType.RGBCONTROLLER_UPDATELEDS,
             struct.calcsize(f"IH{3*(end)}b{(end)}x")
         )
         buff = struct.pack("H", end) + b''.join((color.pack() for color in self._colors[:start])) + (color.pack())*(end - start)
@@ -163,11 +162,11 @@ class Device(utils.RGBObject):
 
     def set_colors(self, colors: List[utils.RGBColor], start: int = 0, end: int = 0, fast: bool = False):
         '''
-        Sets the LEDs colors between start and end
+        Sets the LEDs' colors between start and end
 
-        :param colors: the list of colors, one per led
+        :param colors: the list of colors, one per LED
         :param start: the first LED to change
-        :param end: the last LED to change
+        :param end: the first unchanged LED
         :param fast: If you care more about quickly setting colors than having correct internal state data, then set :code:`fast` to :code:`True`
         '''
         if end == 0:
@@ -176,7 +175,7 @@ class Device(utils.RGBObject):
             raise IndexError("Number of colors doesn't match number of LEDs")
         self.comms.send_header(
             self.id,
-            utils.PacketType.NET_PACKET_ID_RGBCONTROLLER_UPDATELEDS,
+            utils.PacketType.RGBCONTROLLER_UPDATELEDS,
             struct.calcsize(f"IH{3*(end)}b{(end)}x")
         )
         buff = struct.pack("H", end) + b''.join((color.pack() for color in self._colors[:start])) + b''.join((color.pack() for color in colors))
@@ -200,65 +199,60 @@ class Device(utils.RGBObject):
         data = mode.pack()
         self.comms.send_header(
             self.id,
-            utils.PacketType.NET_PACKET_ID_RGBCONTROLLER_UPDATEMODE,
+            utils.PacketType.RGBCONTROLLER_UPDATEMODE,
             len(data)
         )
         self.comms.send_data(data)
-        self.active_mode = mode.id
-        self.data.active_mode = self.active_mode
-        if len(mode.colors) == len(self.colors):
-            self.colors = mode.colors
-            self.data.colors = self.colors
-        self.data.modes = self.modes
+        self.update()
 
     def set_custom_mode(self):
         self.comms.send_header(
             self.id,
-            utils.PacketType.NET_PACKET_ID_RGBCONTROLLER_SETCUSTOMMODE,
+            utils.PacketType.RGBCONTROLLER_SETCUSTOMMODE,
             0
         )
 
 
-class OpenRGBClient(utils.RGBContainer):
+class OpenRGBClient(utils.RGBObject):
     '''
-    This is the only class you should ever need to instantiate.  It initializes
-    the communication, gets the device information, sets the devices to the
-    custom mode and creates Devices, Zones, and LEDs for you.
+    This is the only class you should need to manually instantiate.  It
+    initializes the communication, gets the device information, and creates
+    Devices, Zones, and LEDs for you.
     '''
 
-    def __init__(self, address: str = "127.0.0.1", port: int = 6742, name: str = "openrgb-python", custom: bool = True):
+    def __init__(self, address: str = "127.0.0.1", port: int = 6742, name: str = "openrgb-python"):
         '''
         :param address: the ip address of the SDK server
         :param port: the port of the SDK server
         :param name: the string that will be displayed on the OpenRGB SDK tab's list of clients
-        :param custom: whether or not to set all your devices to custom control mode on initializtion
         '''
         self.device_num = 0
         self.comms = NetworkClient(self._callback, address, port, name)
         self.address = address
         self.port = port
         self.name = name
-        while self.device_num == 0:
-            sleep(.2)
-        self.devices = [None for x in range(self.device_num)]
-        self.get_device_info()
+        self.comms.requestDeviceNum()
         while any((dev is None for dev in self.devices)):
             sleep(.2)
-        if custom:
-            for dev in self.devices:
-                dev.set_custom_mode()
 
     def __repr__(self):
         return f"OpenRGBClient(address={self.address}, port={self.port}, name={self.name})"
 
-    def _callback(self, device: int, type: int, data):
-        if type == utils.PacketType.NET_PACKET_ID_REQUEST_CONTROLLER_COUNT:
-            self.device_num = data
-        elif type == utils.PacketType.NET_PACKET_ID_REQUEST_CONTROLLER_DATA:
-            if self.devices[device] is None:
-                self.devices[device] = Device(data, device, self.comms)
-            else:
-                self.devices[device].__init__(data, device, self.comms)
+    def _callback(self, device: int, type: int, data: Union[int, utils.ControllerData]):
+        if type == utils.PacketType.REQUEST_CONTROLLER_COUNT:
+            if data != self.device_num or data != len(self.devices):
+                self.device_num = data
+                self.devices = [None for x in range(self.device_num)]
+                for x in range(self.device_num):
+                    self.comms.requestDeviceData(x)
+        elif type == utils.PacketType.REQUEST_CONTROLLER_DATA:
+            try:
+                if self.devices[device] is None:
+                    self.devices[device] = Device(data, device, self.comms)
+                else:
+                    self.devices[device].__init__(data, device, self.comms)
+            except IndexError:
+                self.comms.requestDeviceNum()
 
     def set_color(self, color: utils.RGBColor, fast: bool = False):
         '''
@@ -320,12 +314,13 @@ class OpenRGBClient(utils.RGBContainer):
         with open(f'{directory.rstrip("/")}/{name}.orp', 'wb') as f:
             f.write(utils.Profile(self.devices).pack())
 
-    def get_device_info(self):
+    def update(self):
         '''
-        Gets the current state of your devices from the SDK server.  Useful if
-        you change something from the gui or another SDK client and need to
-        sync up the changes.
+        Gets the current state of your devices from the SDK server, which is
+        useful if you change something from the gui or another SDK client and
+        need to sync up the changes.
         '''
+        self.comms.requestDeviceNum()
         for x in range(self.device_num):
             self.comms.requestDeviceData(x)
 
